/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.utils');

org.ametys.utils.Utils = {};

/**
 * Trunk the given text with '...' if the text width is greater than the given max width. 
 * @param {String|HTMLElement} el The element, DOM node or id that the instance will be bound to
 * @param {String} text The text to trunk
 * @param {Number} maxWidth The max width in pixels.
 * @return The truncated text or the full text if the text is not oversized.
 * @static
 */
org.ametys.utils.Utils.getTruncatedText = function (el, text, maxWidth)
{
	var html = document.createElement('div');
	html.innerHTML = text;
	
	var textMesurer = Ext.util.TextMetrics.createInstance(el);
	
	if (textMesurer.getWidth (html.innerHTML) > maxWidth && maxWidth > 0)
	{
		var textNode = org.ametys.utils.Utils._getLastNonEmptyTextNode(html);
		// textNode.nodeValue = textNode.nodeValue + "..."
		
		while (textMesurer.getWidth (html.innerHTML) > maxWidth)
		{
			textNode.nodeValue = textNode.nodeValue.substring (0, textNode.nodeValue.length - 4) + "...";
			textNode = org.ametys.utils.Utils._getLastNonEmptyTextNode(html);
		}
		
		return html.innerHTML;
	}
	else
	{
		return text;
	}
}

org.ametys.utils.Utils._getLastNonEmptyTextNode = function (html)
{
	var lastChild = html.lastChild;
	while (lastChild.lastChild != null)
	{
		lastChild = lastChild.lastChild;
	}
	
	if (lastChild.nodeType == 3) // text
	{
		var text = lastChild.nodeValue;
		if (Ext.isEmpty(text) || text == '...')
		{
			// Remove empty text
			lastChild.parentNode.removeChild(lastChild);
			return org.ametys.utils.Utils._getLastNonEmptyTextNode(html);
		}
		else
		{
			if (text.indexOf('...', text.length - 3) == -1)
			{
				lastChild.nodeValue = text + '...';
			}
			return lastChild;
		}
	}
	else
	{
		// Remove empty tag
		lastChild.parentNode.removeChild(lastChild);
		return org.ametys.utils.Utils._getLastNonEmptyTextNode(html);
	}
	
}